@@ -1,6 +1,8 @@
 package Minion::Job;
 use Mojo::Base 'Mojo::EventEmitter';
 
+use Mojo::IOLoop;
+
 has args => sub { [] };
 has [qw(id minion task)];
 
@@ -38,6 +40,9 @@ sub _child {
   die "Can't fork: $!" unless defined(my $pid = fork);
   return $pid if $pid;
 
+  # Reset event loop
+  Mojo::IOLoop->reset;
+
   # Child
   my $task = $self->task;
   $self->app->log->debug(qq{Performing job "$task" (@{[$self->id]}:$$).});
